# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin

from . import models


class JobLogInline(UserAdminMixin, admin.TabularInline):
    model = models.JobLog
    extra = 1
    readonly_fields = ('date_create', 'elaboration_results', 'is_valid', 'extra_info',)
    exclude = ('elaboration_time', 'date_last_modify', 'creator', 'last_modifier', 'log_file_content',)


class JobAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    advanced_search_fields = ()
    fieldsets = (
        (_('general information'), {
            'fields': (
                ('year', 'month', 'day', 'weekday',),
                ('hour', 'minute',),
                'name',
                'command',
                'parameters',
                'status',
                'is_una_tantum'
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', )
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('status', 'year', 'month', 'day', 'hour', 'minute', 'weekday', 'name', 'ordering', 'is_una_tantum')
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    inlines = (JobLogInline,)


class JobLogAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    advanced_search_fields = ()
    fieldsets = (
        (_('general information'), {
            'fields': (
                'job', 'elaboration_time', 'elaboration_results', 'is_valid', 'extra_info', 'log_file_content',
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ()
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('date_create', 'date_last_modify')
        }),
    )
    list_display = (
        'job', 'elaboration_time', 'elaboration_results', 'is_valid',
    )
    readonly_fields = (
        'date_create', 'date_last_modify',
        'job', 'elaboration_time', 'elaboration_results', 'is_valid', 'extra_info', 'log_file_content',
    )


admin.site.register(models.Job, JobAdmin)
admin.site.register(models.JobLog, JobLogAdmin)
